@@ -177,15 +177,15 @@ class DialogBaseImpl(DialogBase):
         self.__handler.setLevel(logging.INFO)
         if logFormatter is not None:
             self.__handler.setFormatter(logFormatter)
-        l = logging.getLogger(name=constants.Log.LOGGER_BASE)
-        l.addHandler(self.__handler)
+        logger = logging.getLogger(name=constants.Log.LOGGER_BASE)
+        logger.addHandler(self.__handler)
 
     def __restoreStdHandles(self):
         self.__flush(sys.stdout)
         self.__flush(sys.stderr)
         if self.__handler is not None:
-            l = logging.getLogger(name=constants.Log.LOGGER_BASE)
-            l.removeHandler(self.__handler)
+            logger = logging.getLogger(name=constants.Log.LOGGER_BASE)
+            logger.removeHandler(self.__handler)
             self.__handler.close()
             self.__handler = None
         for i in range(3):
@@ -237,7 +237,7 @@ class DialogBaseImpl(DialogBase):
             except RuntimeError as e:
                 # probably signal
                 raise e
-            except:
+            except Exception:
                 self.logger.debug('getpass', exc_info=True)
             finally:
                 os.dup2(old, 0)
